netapp_ontap.models.software_status_details API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.software_status_details`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SoftwareStatusDetailsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SoftwareStatusDetails object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `action GET POST PATCH`

    The action field of the software_status_details.

  `end_time GET`

    End time for each status phase.

    Example: 2019-02-02T19:00:00.000+0000

  `issue GET POST PATCH`

    The issue field of the software_status_details.

  `name GET`

    Name of the phase to be retrieved for status details.

    Example: initialize

  `node GET POST PATCH`

    The node field of the software_status_details.

  `start_time GET`

    Start time for each status phase.

    Example: 2019-02-02T19:00:00.000+0000

  `state GET`

    Status of the phase

    Valid choices:

    - in_progress
    - waiting
    - paused_by_user
    - paused_on_error
    - completed
    - canceled
    - failed
    - pause_pending
    - cancel_pending